/* unicode-versions.h */
/* THIS IS A GENERATED FILE. CHANGES WILL BE OVERWRITTEN. */
/* Generated by ./gen-unicode-headers.pl */
/* Generated from UCD version 16.0.0 */

#pragma once

#include <glib.h>

#ifndef __GTK_DOC_IGNORE__

typedef struct
{
  gunichar start;
  gunichar end;
  FontManagerUnicodeStandard version;
}
FontManagerUnicodeVersion;

static const FontManagerUnicodeVersion unicode_versions[] =
{
  { 0x0000, 0x001F, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0020, 0x007E, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x007F, 0x009F, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x00A0, 0x00AC, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x00AD, 0x00AD, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x00AE, 0x01F5, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x01F6, 0x01F9, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x01FA, 0x0217, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0218, 0x021F, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x0220, 0x0220, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0x0221, 0x0221, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x0222, 0x0233, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x0234, 0x0236, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x0237, 0x0241, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x0242, 0x024F, FONT_MANAGER_UNICODE_VERSION_5_0 },
  { 0x0250, 0x02A8, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x02A9, 0x02AD, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x02AE, 0x02AF, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x02B0, 0x02DE, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x02DF, 0x02DF, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x02E0, 0x02E9, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x02EA, 0x02EE, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x02EF, 0x02FF, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x0300, 0x0345, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0346, 0x034E, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x034F, 0x034F, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0x0350, 0x0357, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x0358, 0x035C, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x035D, 0x035F, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x0360, 0x0361, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0362, 0x0362, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x0363, 0x036F, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0x0370, 0x0373, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x0374, 0x0375, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0376, 0x0377, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x037A, 0x037A, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x037B, 0x037D, FONT_MANAGER_UNICODE_VERSION_5_0 },
  { 0x037E, 0x037E, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x037F, 0x037F, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x0384, 0x038A, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x038C, 0x038C, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x038E, 0x03A1, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x03A3, 0x03CE, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x03CF, 0x03CF, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x03D0, 0x03D6, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x03D7, 0x03D7, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x03D8, 0x03D9, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0x03DA, 0x03DA, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x03DB, 0x03DB, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x03DC, 0x03DC, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x03DD, 0x03DD, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x03DE, 0x03DE, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x03DF, 0x03DF, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x03E0, 0x03E0, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x03E1, 0x03E1, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x03E2, 0x03F3, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x03F4, 0x03F5, FONT_MANAGER_UNICODE_VERSION_3_1 },
  { 0x03F6, 0x03F6, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0x03F7, 0x03FB, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x03FC, 0x03FF, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x0400, 0x0400, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x0401, 0x040C, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x040D, 0x040D, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x040E, 0x044F, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0450, 0x0450, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x0451, 0x045C, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x045D, 0x045D, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x045E, 0x0486, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0487, 0x0487, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x0488, 0x0489, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x048A, 0x048B, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0x048C, 0x048F, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x0490, 0x04C4, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x04C5, 0x04C6, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0x04C7, 0x04C8, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x04C9, 0x04CA, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0x04CB, 0x04CC, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x04CD, 0x04CE, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0x04CF, 0x04CF, FONT_MANAGER_UNICODE_VERSION_5_0 },
  { 0x04D0, 0x04EB, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x04EC, 0x04ED, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x04EE, 0x04F5, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x04F6, 0x04F7, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x04F8, 0x04F9, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x04FA, 0x04FF, FONT_MANAGER_UNICODE_VERSION_5_0 },
  { 0x0500, 0x050F, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0x0510, 0x0513, FONT_MANAGER_UNICODE_VERSION_5_0 },
  { 0x0514, 0x0523, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x0524, 0x0525, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x0526, 0x0527, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x0528, 0x052F, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x0531, 0x0556, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0559, 0x055F, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0560, 0x0560, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0x0561, 0x0587, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0588, 0x0588, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0x0589, 0x0589, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x058A, 0x058A, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x058D, 0x058E, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x058F, 0x058F, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x0591, 0x05A1, FONT_MANAGER_UNICODE_VERSION_2_0 },
  { 0x05A2, 0x05A2, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x05A3, 0x05AF, FONT_MANAGER_UNICODE_VERSION_2_0 },
  { 0x05B0, 0x05B9, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x05BA, 0x05BA, FONT_MANAGER_UNICODE_VERSION_5_0 },
  { 0x05BB, 0x05C3, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x05C4, 0x05C4, FONT_MANAGER_UNICODE_VERSION_2_0 },
  { 0x05C5, 0x05C7, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x05D0, 0x05EA, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x05EF, 0x05EF, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0x05F0, 0x05F4, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0600, 0x0603, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x0604, 0x0604, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x0605, 0x0605, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x0606, 0x060A, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x060B, 0x060B, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x060C, 0x060C, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x060D, 0x0615, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x0616, 0x061A, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x061B, 0x061B, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x061C, 0x061C, FONT_MANAGER_UNICODE_VERSION_6_3 },
  { 0x061D, 0x061D, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x061E, 0x061E, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x061F, 0x061F, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0620, 0x0620, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x0621, 0x063A, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x063B, 0x063F, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x0640, 0x0652, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0653, 0x0655, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x0656, 0x0658, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x0659, 0x065E, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x065F, 0x065F, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x0660, 0x066D, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x066E, 0x066F, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0x0670, 0x06B7, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x06B8, 0x06B9, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x06BA, 0x06BE, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x06BF, 0x06BF, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x06C0, 0x06CE, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x06CF, 0x06CF, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x06D0, 0x06DC, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x06DD, 0x06DD, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x06DE, 0x06ED, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x06EE, 0x06EF, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x06F0, 0x06F9, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x06FA, 0x06FE, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x06FF, 0x06FF, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x0700, 0x070D, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x070F, 0x070F, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x0710, 0x072C, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x072D, 0x072F, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x0730, 0x074A, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x074D, 0x074F, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x0750, 0x076D, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x076E, 0x077F, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x0780, 0x07B0, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x07B1, 0x07B1, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0x07C0, 0x07FA, FONT_MANAGER_UNICODE_VERSION_5_0 },
  { 0x07FD, 0x07FF, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0x0800, 0x082D, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x0830, 0x083E, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x0840, 0x085B, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x085E, 0x085E, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x0860, 0x086A, FONT_MANAGER_UNICODE_VERSION_10_0 },
  { 0x0870, 0x088E, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x0890, 0x0891, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x0897, 0x0897, FONT_MANAGER_UNICODE_VERSION_16_0 },
  { 0x0898, 0x089F, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x08A0, 0x08A0, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x08A1, 0x08A1, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x08A2, 0x08AC, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x08AD, 0x08B2, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x08B3, 0x08B4, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0x08B5, 0x08B5, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x08B6, 0x08BD, FONT_MANAGER_UNICODE_VERSION_9_0 },
  { 0x08BE, 0x08C7, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0x08C8, 0x08D2, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x08D3, 0x08D3, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0x08D4, 0x08E1, FONT_MANAGER_UNICODE_VERSION_9_0 },
  { 0x08E2, 0x08E2, FONT_MANAGER_UNICODE_VERSION_9_0 },
  { 0x08E3, 0x08E3, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0x08E4, 0x08FE, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x08FF, 0x08FF, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x0900, 0x0900, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x0901, 0x0903, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0904, 0x0904, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x0905, 0x0939, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x093A, 0x093B, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x093C, 0x094D, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x094E, 0x094E, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x094F, 0x094F, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x0950, 0x0954, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0955, 0x0955, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x0956, 0x0957, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x0958, 0x0970, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0971, 0x0972, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x0973, 0x0977, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x0978, 0x0978, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x0979, 0x097A, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x097B, 0x097C, FONT_MANAGER_UNICODE_VERSION_5_0 },
  { 0x097D, 0x097D, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x097E, 0x097F, FONT_MANAGER_UNICODE_VERSION_5_0 },
  { 0x0980, 0x0980, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x0981, 0x0983, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0985, 0x098C, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x098F, 0x0990, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0993, 0x09A8, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x09AA, 0x09B0, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x09B2, 0x09B2, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x09B6, 0x09B9, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x09BC, 0x09BC, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x09BD, 0x09BD, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x09BE, 0x09C4, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x09C7, 0x09C8, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x09CB, 0x09CD, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x09CE, 0x09CE, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x09D7, 0x09D7, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x09DC, 0x09DD, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x09DF, 0x09E3, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x09E6, 0x09FA, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x09FB, 0x09FB, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x09FC, 0x09FD, FONT_MANAGER_UNICODE_VERSION_10_0 },
  { 0x09FE, 0x09FE, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0x0A01, 0x0A01, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x0A02, 0x0A02, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0A03, 0x0A03, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x0A05, 0x0A0A, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0A0F, 0x0A10, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0A13, 0x0A28, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0A2A, 0x0A30, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0A32, 0x0A33, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0A35, 0x0A36, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0A38, 0x0A39, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0A3C, 0x0A3C, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0A3E, 0x0A42, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0A47, 0x0A48, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0A4B, 0x0A4D, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0A51, 0x0A51, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x0A59, 0x0A5C, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0A5E, 0x0A5E, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0A66, 0x0A74, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0A75, 0x0A75, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x0A76, 0x0A76, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0x0A81, 0x0A83, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0A85, 0x0A8B, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0A8C, 0x0A8C, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x0A8D, 0x0A8D, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0A8F, 0x0A91, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0A93, 0x0AA8, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0AAA, 0x0AB0, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0AB2, 0x0AB3, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0AB5, 0x0AB9, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0ABC, 0x0AC5, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0AC7, 0x0AC9, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0ACB, 0x0ACD, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0AD0, 0x0AD0, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0AE0, 0x0AE0, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0AE1, 0x0AE3, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x0AE6, 0x0AEF, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0AF0, 0x0AF0, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x0AF1, 0x0AF1, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x0AF9, 0x0AF9, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0x0AFA, 0x0AFF, FONT_MANAGER_UNICODE_VERSION_10_0 },
  { 0x0B01, 0x0B03, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0B05, 0x0B0C, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0B0F, 0x0B10, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0B13, 0x0B28, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0B2A, 0x0B30, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0B32, 0x0B33, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0B35, 0x0B35, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x0B36, 0x0B39, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0B3C, 0x0B43, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0B44, 0x0B44, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x0B47, 0x0B48, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0B4B, 0x0B4D, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0B55, 0x0B55, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0x0B56, 0x0B57, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0B5C, 0x0B5D, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0B5F, 0x0B61, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0B62, 0x0B63, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x0B66, 0x0B70, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0B71, 0x0B71, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x0B72, 0x0B77, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x0B82, 0x0B83, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0B85, 0x0B8A, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0B8E, 0x0B90, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0B92, 0x0B95, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0B99, 0x0B9A, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0B9C, 0x0B9C, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0B9E, 0x0B9F, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0BA3, 0x0BA4, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0BA8, 0x0BAA, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0BAE, 0x0BB5, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0BB6, 0x0BB6, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x0BB7, 0x0BB9, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0BBE, 0x0BC2, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0BC6, 0x0BC8, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0BCA, 0x0BCD, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0BD0, 0x0BD0, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x0BD7, 0x0BD7, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0BE6, 0x0BE6, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x0BE7, 0x0BF2, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0BF3, 0x0BFA, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x0C00, 0x0C00, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x0C01, 0x0C03, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0C04, 0x0C04, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0x0C05, 0x0C0C, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0C0E, 0x0C10, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0C12, 0x0C28, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0C2A, 0x0C33, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0C34, 0x0C34, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x0C35, 0x0C39, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0C3C, 0x0C3C, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x0C3D, 0x0C3D, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x0C3E, 0x0C44, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0C46, 0x0C48, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0C4A, 0x0C4D, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0C55, 0x0C56, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0C58, 0x0C59, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x0C5A, 0x0C5A, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0x0C5D, 0x0C5D, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x0C60, 0x0C61, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0C62, 0x0C63, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x0C66, 0x0C6F, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0C77, 0x0C77, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0x0C78, 0x0C7F, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x0C80, 0x0C80, FONT_MANAGER_UNICODE_VERSION_9_0 },
  { 0x0C81, 0x0C81, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x0C82, 0x0C83, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0C84, 0x0C84, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0x0C85, 0x0C8C, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0C8E, 0x0C90, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0C92, 0x0CA8, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0CAA, 0x0CB3, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0CB5, 0x0CB9, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0CBC, 0x0CBD, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x0CBE, 0x0CC4, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0CC6, 0x0CC8, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0CCA, 0x0CCD, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0CD5, 0x0CD6, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0CDD, 0x0CDD, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x0CDE, 0x0CDE, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0CE0, 0x0CE1, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0CE2, 0x0CE3, FONT_MANAGER_UNICODE_VERSION_5_0 },
  { 0x0CE6, 0x0CEF, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0CF1, 0x0CF2, FONT_MANAGER_UNICODE_VERSION_5_0 },
  { 0x0CF3, 0x0CF3, FONT_MANAGER_UNICODE_VERSION_15_0 },
  { 0x0D00, 0x0D00, FONT_MANAGER_UNICODE_VERSION_10_0 },
  { 0x0D01, 0x0D01, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x0D02, 0x0D03, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0D04, 0x0D04, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0x0D05, 0x0D0C, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0D0E, 0x0D10, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0D12, 0x0D28, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0D29, 0x0D29, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x0D2A, 0x0D39, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0D3A, 0x0D3A, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x0D3B, 0x0D3C, FONT_MANAGER_UNICODE_VERSION_10_0 },
  { 0x0D3D, 0x0D3D, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x0D3E, 0x0D43, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0D44, 0x0D44, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x0D46, 0x0D48, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0D4A, 0x0D4D, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0D4E, 0x0D4E, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x0D4F, 0x0D4F, FONT_MANAGER_UNICODE_VERSION_9_0 },
  { 0x0D54, 0x0D56, FONT_MANAGER_UNICODE_VERSION_9_0 },
  { 0x0D57, 0x0D57, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0D58, 0x0D5E, FONT_MANAGER_UNICODE_VERSION_9_0 },
  { 0x0D5F, 0x0D5F, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0x0D60, 0x0D61, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0D62, 0x0D63, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x0D66, 0x0D6F, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0D70, 0x0D75, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x0D76, 0x0D78, FONT_MANAGER_UNICODE_VERSION_9_0 },
  { 0x0D79, 0x0D7F, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x0D81, 0x0D81, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0x0D82, 0x0D83, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x0D85, 0x0D96, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x0D9A, 0x0DB1, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x0DB3, 0x0DBB, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x0DBD, 0x0DBD, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x0DC0, 0x0DC6, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x0DCA, 0x0DCA, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x0DCF, 0x0DD4, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x0DD6, 0x0DD6, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x0DD8, 0x0DDF, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x0DE6, 0x0DEF, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x0DF2, 0x0DF4, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x0E01, 0x0E3A, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0E3F, 0x0E5B, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0E81, 0x0E82, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0E84, 0x0E84, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0E86, 0x0E86, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0x0E87, 0x0E88, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0E89, 0x0E89, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0x0E8A, 0x0E8A, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0E8C, 0x0E8C, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0x0E8D, 0x0E8D, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0E8E, 0x0E93, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0x0E94, 0x0E97, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0E98, 0x0E98, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0x0E99, 0x0E9F, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0EA0, 0x0EA0, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0x0EA1, 0x0EA3, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0EA5, 0x0EA5, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0EA7, 0x0EA7, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0EA8, 0x0EA9, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0x0EAA, 0x0EAB, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0EAC, 0x0EAC, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0x0EAD, 0x0EB9, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0EBA, 0x0EBA, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0x0EBB, 0x0EBD, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0EC0, 0x0EC4, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0EC6, 0x0EC6, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0EC8, 0x0ECD, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0ECE, 0x0ECE, FONT_MANAGER_UNICODE_VERSION_15_0 },
  { 0x0ED0, 0x0ED9, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0EDC, 0x0EDD, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x0EDE, 0x0EDF, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x0F00, 0x0F47, FONT_MANAGER_UNICODE_VERSION_2_0 },
  { 0x0F49, 0x0F69, FONT_MANAGER_UNICODE_VERSION_2_0 },
  { 0x0F6A, 0x0F6A, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x0F6B, 0x0F6C, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x0F71, 0x0F8B, FONT_MANAGER_UNICODE_VERSION_2_0 },
  { 0x0F8C, 0x0F8F, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x0F90, 0x0F95, FONT_MANAGER_UNICODE_VERSION_2_0 },
  { 0x0F96, 0x0F96, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x0F97, 0x0F97, FONT_MANAGER_UNICODE_VERSION_2_0 },
  { 0x0F99, 0x0FAD, FONT_MANAGER_UNICODE_VERSION_2_0 },
  { 0x0FAE, 0x0FB0, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x0FB1, 0x0FB7, FONT_MANAGER_UNICODE_VERSION_2_0 },
  { 0x0FB8, 0x0FB8, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x0FB9, 0x0FB9, FONT_MANAGER_UNICODE_VERSION_2_0 },
  { 0x0FBA, 0x0FBC, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x0FBE, 0x0FCC, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x0FCE, 0x0FCE, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x0FCF, 0x0FCF, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x0FD0, 0x0FD1, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x0FD2, 0x0FD4, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x0FD5, 0x0FD8, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x0FD9, 0x0FDA, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x1000, 0x1021, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x1022, 0x1022, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x1023, 0x1027, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x1028, 0x1028, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x1029, 0x102A, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x102B, 0x102B, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x102C, 0x1032, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x1033, 0x1035, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x1036, 0x1039, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x103A, 0x103F, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x1040, 0x1059, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x105A, 0x1099, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x109A, 0x109D, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x109E, 0x109F, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x10A0, 0x10C5, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x10C7, 0x10C7, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x10CD, 0x10CD, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x10D0, 0x10F6, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x10F7, 0x10F8, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0x10F9, 0x10FA, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x10FB, 0x10FB, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x10FC, 0x10FC, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x10FD, 0x10FF, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x1100, 0x1159, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x115A, 0x115E, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x115F, 0x11A2, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x11A3, 0x11A7, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x11A8, 0x11F9, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x11FA, 0x11FF, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x1200, 0x1206, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x1207, 0x1207, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x1208, 0x1246, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x1247, 0x1247, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x1248, 0x1248, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x124A, 0x124D, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x1250, 0x1256, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x1258, 0x1258, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x125A, 0x125D, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x1260, 0x1286, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x1287, 0x1287, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x1288, 0x1288, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x128A, 0x128D, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x1290, 0x12AE, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x12AF, 0x12AF, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x12B0, 0x12B0, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x12B2, 0x12B5, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x12B8, 0x12BE, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x12C0, 0x12C0, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x12C2, 0x12C5, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x12C8, 0x12CE, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x12CF, 0x12CF, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x12D0, 0x12D6, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x12D8, 0x12EE, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x12EF, 0x12EF, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x12F0, 0x130E, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x130F, 0x130F, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x1310, 0x1310, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x1312, 0x1315, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x1318, 0x131E, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x131F, 0x131F, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x1320, 0x1346, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x1347, 0x1347, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x1348, 0x135A, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x135D, 0x135E, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x135F, 0x1360, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x1361, 0x137C, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x1380, 0x1399, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x13A0, 0x13F4, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x13F5, 0x13F5, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0x13F8, 0x13FD, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0x1400, 0x1400, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x1401, 0x1676, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x1677, 0x167F, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x1680, 0x169C, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x16A0, 0x16F0, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x16F1, 0x16F8, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x1700, 0x170C, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0x170D, 0x170D, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x170E, 0x1714, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0x1715, 0x1715, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x171F, 0x171F, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x1720, 0x1736, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0x1740, 0x1753, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0x1760, 0x176C, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0x176E, 0x1770, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0x1772, 0x1773, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0x1780, 0x17DC, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x17DD, 0x17DD, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x17E0, 0x17E9, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x17F0, 0x17F9, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x1800, 0x180D, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x180E, 0x180E, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x180F, 0x180F, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x1810, 0x1819, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x1820, 0x1877, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x1878, 0x1878, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0x1880, 0x18A9, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x18AA, 0x18AA, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x18B0, 0x18F5, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x1900, 0x191C, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x191D, 0x191E, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x1920, 0x192B, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x1930, 0x193B, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x1940, 0x1940, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x1944, 0x196D, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x1970, 0x1974, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x1980, 0x19A9, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x19AA, 0x19AB, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x19B0, 0x19C9, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x19D0, 0x19D9, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x19DA, 0x19DA, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x19DE, 0x19DF, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x19E0, 0x19FF, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x1A00, 0x1A1B, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x1A1E, 0x1A1F, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x1A20, 0x1A5E, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x1A60, 0x1A7C, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x1A7F, 0x1A89, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x1A90, 0x1A99, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x1AA0, 0x1AAD, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x1AB0, 0x1ABE, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x1ABF, 0x1AC0, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0x1AC1, 0x1ACE, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x1B00, 0x1B4B, FONT_MANAGER_UNICODE_VERSION_5_0 },
  { 0x1B4C, 0x1B4C, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x1B4E, 0x1B4F, FONT_MANAGER_UNICODE_VERSION_16_0 },
  { 0x1B50, 0x1B7C, FONT_MANAGER_UNICODE_VERSION_5_0 },
  { 0x1B7D, 0x1B7E, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x1B7F, 0x1B7F, FONT_MANAGER_UNICODE_VERSION_16_0 },
  { 0x1B80, 0x1BAA, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x1BAB, 0x1BAD, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x1BAE, 0x1BB9, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x1BBA, 0x1BBF, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x1BC0, 0x1BF3, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x1BFC, 0x1BFF, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x1C00, 0x1C37, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x1C3B, 0x1C49, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x1C4D, 0x1C7F, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x1C80, 0x1C88, FONT_MANAGER_UNICODE_VERSION_9_0 },
  { 0x1C89, 0x1C8A, FONT_MANAGER_UNICODE_VERSION_16_0 },
  { 0x1C90, 0x1CBA, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0x1CBD, 0x1CBF, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0x1CC0, 0x1CC7, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x1CD0, 0x1CF2, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x1CF3, 0x1CF6, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x1CF7, 0x1CF7, FONT_MANAGER_UNICODE_VERSION_10_0 },
  { 0x1CF8, 0x1CF9, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x1CFA, 0x1CFA, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0x1D00, 0x1D6B, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x1D6C, 0x1DC3, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x1DC4, 0x1DCA, FONT_MANAGER_UNICODE_VERSION_5_0 },
  { 0x1DCB, 0x1DE6, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x1DE7, 0x1DF5, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x1DF6, 0x1DF9, FONT_MANAGER_UNICODE_VERSION_10_0 },
  { 0x1DFA, 0x1DFA, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x1DFB, 0x1DFB, FONT_MANAGER_UNICODE_VERSION_9_0 },
  { 0x1DFC, 0x1DFC, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x1DFD, 0x1DFD, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x1DFE, 0x1DFF, FONT_MANAGER_UNICODE_VERSION_5_0 },
  { 0x1E00, 0x1E9A, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x1E9B, 0x1E9B, FONT_MANAGER_UNICODE_VERSION_2_0 },
  { 0x1E9C, 0x1E9F, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x1EA0, 0x1EF9, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x1EFA, 0x1EFF, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x1F00, 0x1F15, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x1F18, 0x1F1D, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x1F20, 0x1F45, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x1F48, 0x1F4D, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x1F50, 0x1F57, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x1F59, 0x1F59, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x1F5B, 0x1F5B, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x1F5D, 0x1F5D, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x1F5F, 0x1F7D, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x1F80, 0x1FB4, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x1FB6, 0x1FC4, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x1FC6, 0x1FD3, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x1FD6, 0x1FDB, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x1FDD, 0x1FEF, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x1FF2, 0x1FF4, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x1FF6, 0x1FFE, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x2000, 0x200A, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x200B, 0x200F, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x2010, 0x2027, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x2028, 0x202E, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x202F, 0x202F, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x2030, 0x2046, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x2047, 0x2047, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0x2048, 0x204D, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x204E, 0x2052, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0x2053, 0x2054, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x2055, 0x2056, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x2057, 0x2057, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0x2058, 0x205E, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x205F, 0x205F, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0x2060, 0x2063, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0x2064, 0x2064, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x2066, 0x2069, FONT_MANAGER_UNICODE_VERSION_6_3 },
  { 0x206A, 0x206F, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x2070, 0x2070, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x2071, 0x2071, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0x2074, 0x208E, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x2090, 0x2094, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x2095, 0x209C, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x20A0, 0x20AA, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x20AB, 0x20AB, FONT_MANAGER_UNICODE_VERSION_2_0 },
  { 0x20AC, 0x20AC, FONT_MANAGER_UNICODE_VERSION_2_1 },
  { 0x20AD, 0x20AF, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x20B0, 0x20B1, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0x20B2, 0x20B5, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x20B6, 0x20B8, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x20B9, 0x20B9, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x20BA, 0x20BA, FONT_MANAGER_UNICODE_VERSION_6_2 },
  { 0x20BB, 0x20BD, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x20BE, 0x20BE, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0x20BF, 0x20BF, FONT_MANAGER_UNICODE_VERSION_10_0 },
  { 0x20C0, 0x20C0, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x20D0, 0x20E1, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x20E2, 0x20E3, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x20E4, 0x20EA, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0x20EB, 0x20EB, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x20EC, 0x20EF, FONT_MANAGER_UNICODE_VERSION_5_0 },
  { 0x20F0, 0x20F0, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x2100, 0x2138, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x2139, 0x213A, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x213B, 0x213B, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x213C, 0x213C, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x213D, 0x214B, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0x214C, 0x214C, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x214D, 0x214E, FONT_MANAGER_UNICODE_VERSION_5_0 },
  { 0x214F, 0x214F, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x2150, 0x2152, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x2153, 0x2182, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x2183, 0x2183, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x2184, 0x2184, FONT_MANAGER_UNICODE_VERSION_5_0 },
  { 0x2185, 0x2188, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x2189, 0x2189, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x218A, 0x218B, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0x2190, 0x21EA, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x21EB, 0x21F3, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x21F4, 0x21FF, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0x2200, 0x22F1, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x22F2, 0x22FF, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0x2300, 0x2300, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x2301, 0x2301, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x2302, 0x237A, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x237B, 0x237B, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x237C, 0x237C, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0x237D, 0x239A, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x239B, 0x23CE, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0x23CF, 0x23D0, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x23D1, 0x23DB, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x23DC, 0x23E7, FONT_MANAGER_UNICODE_VERSION_5_0 },
  { 0x23E8, 0x23E8, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x23E9, 0x23F3, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x23F4, 0x23FA, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x23FB, 0x23FE, FONT_MANAGER_UNICODE_VERSION_9_0 },
  { 0x23FF, 0x23FF, FONT_MANAGER_UNICODE_VERSION_10_0 },
  { 0x2400, 0x2424, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x2425, 0x2426, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x2427, 0x2429, FONT_MANAGER_UNICODE_VERSION_16_0 },
  { 0x2440, 0x244A, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x2460, 0x24EA, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x24EB, 0x24FE, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0x24FF, 0x24FF, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x2500, 0x2595, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x2596, 0x259F, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0x25A0, 0x25EF, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x25F0, 0x25F7, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x25F8, 0x25FF, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0x2600, 0x2613, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x2614, 0x2615, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x2616, 0x2617, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0x2618, 0x2618, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x2619, 0x2619, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x261A, 0x266F, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x2670, 0x2671, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x2672, 0x267D, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0x267E, 0x267F, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x2680, 0x2689, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0x268A, 0x2691, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x2692, 0x269C, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x269D, 0x269D, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x269E, 0x269F, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x26A0, 0x26A1, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x26A2, 0x26B1, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x26B2, 0x26B2, FONT_MANAGER_UNICODE_VERSION_5_0 },
  { 0x26B3, 0x26BC, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x26BD, 0x26BF, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x26C0, 0x26C3, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x26C4, 0x26CD, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x26CE, 0x26CE, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x26CF, 0x26E1, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x26E2, 0x26E2, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x26E3, 0x26E3, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x26E4, 0x26E7, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x26E8, 0x26FF, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x2700, 0x2700, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x2701, 0x2704, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x2705, 0x2705, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x2706, 0x2709, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x270A, 0x270B, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x270C, 0x2727, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x2728, 0x2728, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x2729, 0x274B, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x274C, 0x274C, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x274D, 0x274D, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x274E, 0x274E, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x274F, 0x2752, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x2753, 0x2755, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x2756, 0x2756, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x2757, 0x2757, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x2758, 0x275E, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x275F, 0x2760, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x2761, 0x2767, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x2768, 0x2775, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0x2776, 0x2794, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x2795, 0x2797, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x2798, 0x27AF, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x27B0, 0x27B0, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x27B1, 0x27BE, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x27BF, 0x27BF, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x27C0, 0x27C6, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x27C7, 0x27CA, FONT_MANAGER_UNICODE_VERSION_5_0 },
  { 0x27CB, 0x27CB, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x27CC, 0x27CC, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x27CD, 0x27CD, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x27CE, 0x27CF, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x27D0, 0x27EB, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0x27EC, 0x27EF, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x27F0, 0x27FF, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0x2800, 0x28FF, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x2900, 0x2AFF, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0x2B00, 0x2B0D, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x2B0E, 0x2B13, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x2B14, 0x2B1A, FONT_MANAGER_UNICODE_VERSION_5_0 },
  { 0x2B1B, 0x2B1F, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x2B20, 0x2B23, FONT_MANAGER_UNICODE_VERSION_5_0 },
  { 0x2B24, 0x2B4C, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x2B4D, 0x2B4F, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x2B50, 0x2B54, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x2B55, 0x2B59, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x2B5A, 0x2B73, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x2B76, 0x2B95, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x2B97, 0x2B97, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0x2B98, 0x2BB9, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x2BBA, 0x2BBC, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0x2BBD, 0x2BC8, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x2BC9, 0x2BC9, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0x2BCA, 0x2BD1, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x2BD2, 0x2BD2, FONT_MANAGER_UNICODE_VERSION_10_0 },
  { 0x2BD3, 0x2BEB, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0x2BEC, 0x2BEF, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0x2BF0, 0x2BFE, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0x2BFF, 0x2BFF, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0x2C00, 0x2C2E, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x2C2F, 0x2C2F, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x2C30, 0x2C5E, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x2C5F, 0x2C5F, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x2C60, 0x2C6C, FONT_MANAGER_UNICODE_VERSION_5_0 },
  { 0x2C6D, 0x2C6F, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x2C70, 0x2C70, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x2C71, 0x2C73, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x2C74, 0x2C77, FONT_MANAGER_UNICODE_VERSION_5_0 },
  { 0x2C78, 0x2C7D, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x2C7E, 0x2C7F, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x2C80, 0x2CEA, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x2CEB, 0x2CF1, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x2CF2, 0x2CF3, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x2CF9, 0x2D25, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x2D27, 0x2D27, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x2D2D, 0x2D2D, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x2D30, 0x2D65, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x2D66, 0x2D67, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x2D6F, 0x2D6F, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x2D70, 0x2D70, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x2D7F, 0x2D7F, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x2D80, 0x2D96, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x2DA0, 0x2DA6, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x2DA8, 0x2DAE, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x2DB0, 0x2DB6, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x2DB8, 0x2DBE, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x2DC0, 0x2DC6, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x2DC8, 0x2DCE, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x2DD0, 0x2DD6, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x2DD8, 0x2DDE, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x2DE0, 0x2DFF, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x2E00, 0x2E17, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x2E18, 0x2E1B, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x2E1C, 0x2E1D, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x2E1E, 0x2E30, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x2E31, 0x2E31, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x2E32, 0x2E3B, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x2E3C, 0x2E42, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x2E43, 0x2E44, FONT_MANAGER_UNICODE_VERSION_9_0 },
  { 0x2E45, 0x2E49, FONT_MANAGER_UNICODE_VERSION_10_0 },
  { 0x2E4A, 0x2E4E, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0x2E4F, 0x2E4F, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0x2E50, 0x2E52, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0x2E53, 0x2E5D, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x2E80, 0x2E99, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x2E9B, 0x2EF3, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x2F00, 0x2FD5, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x2FF0, 0x2FFB, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x2FFC, 0x2FFF, FONT_MANAGER_UNICODE_VERSION_15_1 },
  { 0x3000, 0x3037, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x3038, 0x303A, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x303B, 0x303D, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0x303E, 0x303E, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x303F, 0x303F, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x3041, 0x3094, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x3095, 0x3096, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0x3099, 0x309E, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x309F, 0x30A0, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0x30A1, 0x30FE, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x30FF, 0x30FF, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0x3105, 0x312C, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x312D, 0x312D, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x312E, 0x312E, FONT_MANAGER_UNICODE_VERSION_10_0 },
  { 0x312F, 0x312F, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0x3131, 0x318E, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x3190, 0x319F, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x31A0, 0x31B7, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x31B8, 0x31BA, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x31BB, 0x31BF, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0x31C0, 0x31CF, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x31D0, 0x31E3, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x31E4, 0x31E5, FONT_MANAGER_UNICODE_VERSION_16_0 },
  { 0x31EF, 0x31EF, FONT_MANAGER_UNICODE_VERSION_15_1 },
  { 0x31F0, 0x31FF, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0x3200, 0x321C, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x321D, 0x321E, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x3220, 0x3243, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x3244, 0x324F, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x3250, 0x3250, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x3251, 0x325F, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0x3260, 0x327B, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x327C, 0x327D, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x327E, 0x327E, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x327F, 0x32B0, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x32B1, 0x32BF, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0x32C0, 0x32CB, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x32CC, 0x32CF, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x32D0, 0x32FE, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x32FF, 0x32FF, FONT_MANAGER_UNICODE_VERSION_12_1 },
  { 0x3300, 0x3376, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x3377, 0x337A, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x337B, 0x33DD, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x33DE, 0x33DF, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x33E0, 0x33FE, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x33FF, 0x33FF, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x3400, 0x4DB5, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0x4DB6, 0x4DBF, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0x4DC0, 0x4DFF, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x4E00, 0x9FA5, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x9FA6, 0x9FBB, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x9FBC, 0x9FC3, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x9FC4, 0x9FCB, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x9FCC, 0x9FCC, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x9FCD, 0x9FD5, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0x9FD6, 0x9FEA, FONT_MANAGER_UNICODE_VERSION_10_0 },
  { 0x9FEB, 0x9FEF, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0x9FF0, 0x9FFC, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0x9FFD, 0x9FFF, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0xA000, 0xA48C, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0xA490, 0xA4A1, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0xA4A2, 0xA4A3, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0xA4A4, 0xA4B3, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0xA4B4, 0xA4B4, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0xA4B5, 0xA4C0, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0xA4C1, 0xA4C1, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0xA4C2, 0xA4C4, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0xA4C5, 0xA4C5, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0xA4C6, 0xA4C6, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0xA4D0, 0xA4FF, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0xA500, 0xA62B, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0xA640, 0xA65F, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0xA660, 0xA661, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0xA662, 0xA673, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0xA674, 0xA67B, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0xA67C, 0xA697, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0xA698, 0xA69D, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0xA69E, 0xA69E, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0xA69F, 0xA69F, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0xA6A0, 0xA6F7, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0xA700, 0xA716, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0xA717, 0xA71A, FONT_MANAGER_UNICODE_VERSION_5_0 },
  { 0xA71B, 0xA71F, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0xA720, 0xA721, FONT_MANAGER_UNICODE_VERSION_5_0 },
  { 0xA722, 0xA78C, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0xA78D, 0xA78E, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0xA78F, 0xA78F, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0xA790, 0xA791, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0xA792, 0xA793, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0xA794, 0xA79F, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0xA7A0, 0xA7A9, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0xA7AA, 0xA7AA, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0xA7AB, 0xA7AD, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0xA7AE, 0xA7AE, FONT_MANAGER_UNICODE_VERSION_9_0 },
  { 0xA7AF, 0xA7AF, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0xA7B0, 0xA7B1, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0xA7B2, 0xA7B7, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0xA7B8, 0xA7B9, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0xA7BA, 0xA7BF, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0xA7C0, 0xA7C1, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0xA7C2, 0xA7C6, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0xA7C7, 0xA7CA, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0xA7CB, 0xA7CD, FONT_MANAGER_UNICODE_VERSION_16_0 },
  { 0xA7D0, 0xA7D1, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0xA7D3, 0xA7D3, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0xA7D5, 0xA7D9, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0xA7DA, 0xA7DC, FONT_MANAGER_UNICODE_VERSION_16_0 },
  { 0xA7F2, 0xA7F4, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0xA7F5, 0xA7F6, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0xA7F7, 0xA7F7, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0xA7F8, 0xA7F9, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0xA7FA, 0xA7FA, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0xA7FB, 0xA7FF, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0xA800, 0xA82B, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0xA82C, 0xA82C, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0xA830, 0xA839, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0xA840, 0xA877, FONT_MANAGER_UNICODE_VERSION_5_0 },
  { 0xA880, 0xA8C4, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0xA8C5, 0xA8C5, FONT_MANAGER_UNICODE_VERSION_9_0 },
  { 0xA8CE, 0xA8D9, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0xA8E0, 0xA8FB, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0xA8FC, 0xA8FD, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0xA8FE, 0xA8FF, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0xA900, 0xA953, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0xA95F, 0xA95F, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0xA960, 0xA97C, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0xA980, 0xA9CD, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0xA9CF, 0xA9D9, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0xA9DE, 0xA9DF, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0xA9E0, 0xA9FE, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0xAA00, 0xAA36, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0xAA40, 0xAA4D, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0xAA50, 0xAA59, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0xAA5C, 0xAA5F, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0xAA60, 0xAA7B, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0xAA7C, 0xAA7F, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0xAA80, 0xAAC2, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0xAADB, 0xAADF, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0xAAE0, 0xAAF6, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0xAB01, 0xAB06, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0xAB09, 0xAB0E, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0xAB11, 0xAB16, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0xAB20, 0xAB26, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0xAB28, 0xAB2E, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0xAB30, 0xAB5F, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0xAB60, 0xAB63, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0xAB64, 0xAB65, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0xAB66, 0xAB67, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0xAB68, 0xAB6B, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0xAB70, 0xABBF, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0xABC0, 0xABED, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0xABF0, 0xABF9, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0xAC00, 0xD7A3, FONT_MANAGER_UNICODE_VERSION_2_0 },
  { 0xD7B0, 0xD7C6, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0xD7CB, 0xD7FB, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0xD800, 0xDFFF, FONT_MANAGER_UNICODE_VERSION_2_0 },
  { 0xE000, 0xF8FF, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0xF900, 0xFA2D, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0xFA2E, 0xFA2F, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0xFA30, 0xFA6A, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0xFA6B, 0xFA6D, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0xFA70, 0xFAD9, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0xFB00, 0xFB06, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0xFB13, 0xFB17, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0xFB1D, 0xFB1D, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0xFB1E, 0xFB36, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0xFB38, 0xFB3C, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0xFB3E, 0xFB3E, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0xFB40, 0xFB41, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0xFB43, 0xFB44, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0xFB46, 0xFBB1, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0xFBB2, 0xFBC1, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0xFBC2, 0xFBC2, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0xFBD3, 0xFD3F, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0xFD40, 0xFD4F, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0xFD50, 0xFD8F, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0xFD92, 0xFDC7, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0xFDCF, 0xFDCF, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0xFDD0, 0xFDEF, FONT_MANAGER_UNICODE_VERSION_3_1 },
  { 0xFDF0, 0xFDFB, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0xFDFC, 0xFDFC, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0xFDFD, 0xFDFD, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0xFDFE, 0xFDFF, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0xFE00, 0xFE0F, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0xFE10, 0xFE19, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0xFE20, 0xFE23, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0xFE24, 0xFE26, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0xFE27, 0xFE2D, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0xFE2E, 0xFE2F, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0xFE30, 0xFE44, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0xFE45, 0xFE46, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0xFE47, 0xFE48, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0xFE49, 0xFE52, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0xFE54, 0xFE66, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0xFE68, 0xFE6B, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0xFE70, 0xFE72, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0xFE73, 0xFE73, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0xFE74, 0xFE74, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0xFE76, 0xFEFC, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0xFEFF, 0xFEFF, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0xFF01, 0xFF5E, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0xFF5F, 0xFF60, FONT_MANAGER_UNICODE_VERSION_3_2 },
  { 0xFF61, 0xFFBE, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0xFFC2, 0xFFC7, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0xFFCA, 0xFFCF, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0xFFD2, 0xFFD7, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0xFFDA, 0xFFDC, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0xFFE0, 0xFFE6, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0xFFE8, 0xFFEE, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0xFFF9, 0xFFFB, FONT_MANAGER_UNICODE_VERSION_3_0 },
  { 0xFFFC, 0xFFFC, FONT_MANAGER_UNICODE_VERSION_2_1 },
  { 0xFFFD, 0xFFFD, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0xFFFE, 0xFFFF, FONT_MANAGER_UNICODE_VERSION_1_1 },
  { 0x10000, 0x1000B, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x1000D, 0x10026, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x10028, 0x1003A, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x1003C, 0x1003D, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x1003F, 0x1004D, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x10050, 0x1005D, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x10080, 0x100FA, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x10100, 0x10102, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x10107, 0x10133, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x10137, 0x1013F, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x10140, 0x1018A, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x1018B, 0x1018C, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x1018D, 0x1018E, FONT_MANAGER_UNICODE_VERSION_9_0 },
  { 0x10190, 0x1019B, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x1019C, 0x1019C, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0x101A0, 0x101A0, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x101D0, 0x101FD, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x10280, 0x1029C, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x102A0, 0x102D0, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x102E0, 0x102FB, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x10300, 0x1031E, FONT_MANAGER_UNICODE_VERSION_3_1 },
  { 0x1031F, 0x1031F, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x10320, 0x10323, FONT_MANAGER_UNICODE_VERSION_3_1 },
  { 0x1032D, 0x1032F, FONT_MANAGER_UNICODE_VERSION_10_0 },
  { 0x10330, 0x1034A, FONT_MANAGER_UNICODE_VERSION_3_1 },
  { 0x10350, 0x1037A, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x10380, 0x1039D, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x1039F, 0x1039F, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x103A0, 0x103C3, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x103C8, 0x103D5, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x10400, 0x10425, FONT_MANAGER_UNICODE_VERSION_3_1 },
  { 0x10426, 0x10427, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x10428, 0x1044D, FONT_MANAGER_UNICODE_VERSION_3_1 },
  { 0x1044E, 0x1049D, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x104A0, 0x104A9, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x104B0, 0x104D3, FONT_MANAGER_UNICODE_VERSION_9_0 },
  { 0x104D8, 0x104FB, FONT_MANAGER_UNICODE_VERSION_9_0 },
  { 0x10500, 0x10527, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x10530, 0x10563, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x1056F, 0x1056F, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x10570, 0x1057A, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x1057C, 0x1058A, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x1058C, 0x10592, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x10594, 0x10595, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x10597, 0x105A1, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x105A3, 0x105B1, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x105B3, 0x105B9, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x105BB, 0x105BC, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x105C0, 0x105F3, FONT_MANAGER_UNICODE_VERSION_16_0 },
  { 0x10600, 0x10736, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x10740, 0x10755, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x10760, 0x10767, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x10780, 0x10785, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x10787, 0x107B0, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x107B2, 0x107BA, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x10800, 0x10805, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x10808, 0x10808, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x1080A, 0x10835, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x10837, 0x10838, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x1083C, 0x1083C, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x1083F, 0x1083F, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x10840, 0x10855, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x10857, 0x1085F, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x10860, 0x1089E, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x108A7, 0x108AF, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x108E0, 0x108F2, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0x108F4, 0x108F5, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0x108FB, 0x108FF, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0x10900, 0x10919, FONT_MANAGER_UNICODE_VERSION_5_0 },
  { 0x1091A, 0x1091B, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x1091F, 0x1091F, FONT_MANAGER_UNICODE_VERSION_5_0 },
  { 0x10920, 0x10939, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x1093F, 0x1093F, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x10980, 0x109B7, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x109BC, 0x109BD, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0x109BE, 0x109BF, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x109C0, 0x109CF, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0x109D2, 0x109FF, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0x10A00, 0x10A03, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x10A05, 0x10A06, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x10A0C, 0x10A13, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x10A15, 0x10A17, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x10A19, 0x10A33, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x10A34, 0x10A35, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0x10A38, 0x10A3A, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x10A3F, 0x10A47, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x10A48, 0x10A48, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0x10A50, 0x10A58, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x10A60, 0x10A7F, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x10A80, 0x10A9F, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x10AC0, 0x10AE6, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x10AEB, 0x10AF6, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x10B00, 0x10B35, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x10B39, 0x10B55, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x10B58, 0x10B72, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x10B78, 0x10B7F, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x10B80, 0x10B91, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x10B99, 0x10B9C, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x10BA9, 0x10BAF, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x10C00, 0x10C48, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x10C80, 0x10CB2, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0x10CC0, 0x10CF2, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0x10CFA, 0x10CFF, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0x10D00, 0x10D27, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0x10D30, 0x10D39, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0x10D40, 0x10D65, FONT_MANAGER_UNICODE_VERSION_16_0 },
  { 0x10D69, 0x10D85, FONT_MANAGER_UNICODE_VERSION_16_0 },
  { 0x10D8E, 0x10D8F, FONT_MANAGER_UNICODE_VERSION_16_0 },
  { 0x10E60, 0x10E7E, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x10E80, 0x10EA9, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0x10EAB, 0x10EAD, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0x10EB0, 0x10EB1, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0x10EC2, 0x10EC4, FONT_MANAGER_UNICODE_VERSION_16_0 },
  { 0x10EFC, 0x10EFC, FONT_MANAGER_UNICODE_VERSION_16_0 },
  { 0x10EFD, 0x10EFF, FONT_MANAGER_UNICODE_VERSION_15_0 },
  { 0x10F00, 0x10F27, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0x10F30, 0x10F59, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0x10F70, 0x10F89, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x10FB0, 0x10FCB, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0x10FE0, 0x10FF6, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0x11000, 0x1104D, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x11052, 0x1106F, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x11070, 0x11075, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x1107F, 0x1107F, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x11080, 0x110BC, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x110BD, 0x110BD, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x110BE, 0x110C1, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x110C2, 0x110C2, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x110CD, 0x110CD, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0x110D0, 0x110E8, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x110F0, 0x110F9, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x11100, 0x11134, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x11136, 0x11143, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x11144, 0x11146, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0x11147, 0x11147, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0x11150, 0x11176, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x11180, 0x111C8, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x111C9, 0x111CC, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0x111CD, 0x111CD, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x111CE, 0x111CF, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0x111D0, 0x111D9, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x111DA, 0x111DA, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x111DB, 0x111DF, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0x111E1, 0x111F4, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x11200, 0x11211, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x11213, 0x1123D, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x1123E, 0x1123E, FONT_MANAGER_UNICODE_VERSION_9_0 },
  { 0x1123F, 0x11241, FONT_MANAGER_UNICODE_VERSION_15_0 },
  { 0x11280, 0x11286, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0x11288, 0x11288, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0x1128A, 0x1128D, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0x1128F, 0x1129D, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0x1129F, 0x112A9, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0x112B0, 0x112EA, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x112F0, 0x112F9, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x11300, 0x11300, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0x11301, 0x11303, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x11305, 0x1130C, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x1130F, 0x11310, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x11313, 0x11328, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x1132A, 0x11330, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x11332, 0x11333, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x11335, 0x11339, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x1133B, 0x1133B, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0x1133C, 0x11344, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x11347, 0x11348, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x1134B, 0x1134D, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x11350, 0x11350, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0x11357, 0x11357, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x1135D, 0x11363, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x11366, 0x1136C, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x11370, 0x11374, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x11380, 0x11389, FONT_MANAGER_UNICODE_VERSION_16_0 },
  { 0x1138B, 0x1138B, FONT_MANAGER_UNICODE_VERSION_16_0 },
  { 0x1138E, 0x1138E, FONT_MANAGER_UNICODE_VERSION_16_0 },
  { 0x11390, 0x113B5, FONT_MANAGER_UNICODE_VERSION_16_0 },
  { 0x113B7, 0x113C0, FONT_MANAGER_UNICODE_VERSION_16_0 },
  { 0x113C2, 0x113C2, FONT_MANAGER_UNICODE_VERSION_16_0 },
  { 0x113C5, 0x113C5, FONT_MANAGER_UNICODE_VERSION_16_0 },
  { 0x113C7, 0x113CA, FONT_MANAGER_UNICODE_VERSION_16_0 },
  { 0x113CC, 0x113D5, FONT_MANAGER_UNICODE_VERSION_16_0 },
  { 0x113D7, 0x113D8, FONT_MANAGER_UNICODE_VERSION_16_0 },
  { 0x113E1, 0x113E2, FONT_MANAGER_UNICODE_VERSION_16_0 },
  { 0x11400, 0x11459, FONT_MANAGER_UNICODE_VERSION_9_0 },
  { 0x1145A, 0x1145A, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0x1145B, 0x1145B, FONT_MANAGER_UNICODE_VERSION_9_0 },
  { 0x1145D, 0x1145D, FONT_MANAGER_UNICODE_VERSION_9_0 },
  { 0x1145E, 0x1145E, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0x1145F, 0x1145F, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0x11460, 0x11461, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0x11480, 0x114C7, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x114D0, 0x114D9, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x11580, 0x115B5, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x115B8, 0x115C9, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x115CA, 0x115DD, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0x11600, 0x11644, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x11650, 0x11659, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x11660, 0x1166C, FONT_MANAGER_UNICODE_VERSION_9_0 },
  { 0x11680, 0x116B7, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x116B8, 0x116B8, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0x116B9, 0x116B9, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x116C0, 0x116C9, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x116D0, 0x116E3, FONT_MANAGER_UNICODE_VERSION_16_0 },
  { 0x11700, 0x11719, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0x1171A, 0x1171A, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0x1171D, 0x1172B, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0x11730, 0x1173F, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0x11740, 0x11746, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x11800, 0x1183B, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0x118A0, 0x118F2, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x118FF, 0x118FF, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x11900, 0x11906, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0x11909, 0x11909, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0x1190C, 0x11913, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0x11915, 0x11916, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0x11918, 0x11935, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0x11937, 0x11938, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0x1193B, 0x11946, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0x11950, 0x11959, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0x119A0, 0x119A7, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0x119AA, 0x119D7, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0x119DA, 0x119E4, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0x11A00, 0x11A47, FONT_MANAGER_UNICODE_VERSION_10_0 },
  { 0x11A50, 0x11A83, FONT_MANAGER_UNICODE_VERSION_10_0 },
  { 0x11A84, 0x11A85, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0x11A86, 0x11A9C, FONT_MANAGER_UNICODE_VERSION_10_0 },
  { 0x11A9D, 0x11A9D, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0x11A9E, 0x11AA2, FONT_MANAGER_UNICODE_VERSION_10_0 },
  { 0x11AB0, 0x11ABF, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x11AC0, 0x11AF8, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x11B00, 0x11B09, FONT_MANAGER_UNICODE_VERSION_15_0 },
  { 0x11BC0, 0x11BE1, FONT_MANAGER_UNICODE_VERSION_16_0 },
  { 0x11BF0, 0x11BF9, FONT_MANAGER_UNICODE_VERSION_16_0 },
  { 0x11C00, 0x11C08, FONT_MANAGER_UNICODE_VERSION_9_0 },
  { 0x11C0A, 0x11C36, FONT_MANAGER_UNICODE_VERSION_9_0 },
  { 0x11C38, 0x11C45, FONT_MANAGER_UNICODE_VERSION_9_0 },
  { 0x11C50, 0x11C6C, FONT_MANAGER_UNICODE_VERSION_9_0 },
  { 0x11C70, 0x11C8F, FONT_MANAGER_UNICODE_VERSION_9_0 },
  { 0x11C92, 0x11CA7, FONT_MANAGER_UNICODE_VERSION_9_0 },
  { 0x11CA9, 0x11CB6, FONT_MANAGER_UNICODE_VERSION_9_0 },
  { 0x11D00, 0x11D06, FONT_MANAGER_UNICODE_VERSION_10_0 },
  { 0x11D08, 0x11D09, FONT_MANAGER_UNICODE_VERSION_10_0 },
  { 0x11D0B, 0x11D36, FONT_MANAGER_UNICODE_VERSION_10_0 },
  { 0x11D3A, 0x11D3A, FONT_MANAGER_UNICODE_VERSION_10_0 },
  { 0x11D3C, 0x11D3D, FONT_MANAGER_UNICODE_VERSION_10_0 },
  { 0x11D3F, 0x11D47, FONT_MANAGER_UNICODE_VERSION_10_0 },
  { 0x11D50, 0x11D59, FONT_MANAGER_UNICODE_VERSION_10_0 },
  { 0x11D60, 0x11D65, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0x11D67, 0x11D68, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0x11D6A, 0x11D8E, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0x11D90, 0x11D91, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0x11D93, 0x11D98, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0x11DA0, 0x11DA9, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0x11EE0, 0x11EF8, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0x11F00, 0x11F10, FONT_MANAGER_UNICODE_VERSION_15_0 },
  { 0x11F12, 0x11F3A, FONT_MANAGER_UNICODE_VERSION_15_0 },
  { 0x11F3E, 0x11F59, FONT_MANAGER_UNICODE_VERSION_15_0 },
  { 0x11F5A, 0x11F5A, FONT_MANAGER_UNICODE_VERSION_16_0 },
  { 0x11FB0, 0x11FB0, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0x11FC0, 0x11FF1, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0x11FFF, 0x11FFF, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0x12000, 0x1236E, FONT_MANAGER_UNICODE_VERSION_5_0 },
  { 0x1236F, 0x12398, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x12399, 0x12399, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0x12400, 0x12462, FONT_MANAGER_UNICODE_VERSION_5_0 },
  { 0x12463, 0x1246E, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x12470, 0x12473, FONT_MANAGER_UNICODE_VERSION_5_0 },
  { 0x12474, 0x12474, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x12480, 0x12543, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0x12F90, 0x12FF2, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x13000, 0x1342E, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x1342F, 0x1342F, FONT_MANAGER_UNICODE_VERSION_15_0 },
  { 0x13430, 0x13438, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0x13439, 0x1343F, FONT_MANAGER_UNICODE_VERSION_15_0 },
  { 0x13440, 0x13455, FONT_MANAGER_UNICODE_VERSION_15_0 },
  { 0x13460, 0x143FA, FONT_MANAGER_UNICODE_VERSION_16_0 },
  { 0x14400, 0x14646, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0x16100, 0x16139, FONT_MANAGER_UNICODE_VERSION_16_0 },
  { 0x16800, 0x16A38, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x16A40, 0x16A5E, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x16A60, 0x16A69, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x16A6E, 0x16A6F, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x16A70, 0x16ABE, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x16AC0, 0x16AC9, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x16AD0, 0x16AED, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x16AF0, 0x16AF5, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x16B00, 0x16B45, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x16B50, 0x16B59, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x16B5B, 0x16B61, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x16B63, 0x16B77, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x16B7D, 0x16B8F, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x16D40, 0x16D79, FONT_MANAGER_UNICODE_VERSION_16_0 },
  { 0x16E40, 0x16E9A, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0x16F00, 0x16F44, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x16F45, 0x16F4A, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0x16F4F, 0x16F4F, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0x16F50, 0x16F7E, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x16F7F, 0x16F87, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0x16F8F, 0x16F9F, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x16FE0, 0x16FE0, FONT_MANAGER_UNICODE_VERSION_9_0 },
  { 0x16FE1, 0x16FE1, FONT_MANAGER_UNICODE_VERSION_10_0 },
  { 0x16FE2, 0x16FE3, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0x16FE4, 0x16FE4, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0x16FF0, 0x16FF1, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0x17000, 0x187EC, FONT_MANAGER_UNICODE_VERSION_9_0 },
  { 0x187ED, 0x187F1, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0x187F2, 0x187F7, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0x18800, 0x18AF2, FONT_MANAGER_UNICODE_VERSION_9_0 },
  { 0x18AF3, 0x18CD5, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0x18CFF, 0x18CFF, FONT_MANAGER_UNICODE_VERSION_16_0 },
  { 0x18D00, 0x18D08, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0x1AFF0, 0x1AFF3, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x1AFF5, 0x1AFFB, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x1AFFD, 0x1AFFE, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x1B000, 0x1B001, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x1B002, 0x1B11E, FONT_MANAGER_UNICODE_VERSION_10_0 },
  { 0x1B11F, 0x1B122, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x1B132, 0x1B132, FONT_MANAGER_UNICODE_VERSION_15_0 },
  { 0x1B150, 0x1B152, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0x1B155, 0x1B155, FONT_MANAGER_UNICODE_VERSION_15_0 },
  { 0x1B164, 0x1B167, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0x1B170, 0x1B2FB, FONT_MANAGER_UNICODE_VERSION_10_0 },
  { 0x1BC00, 0x1BC6A, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x1BC70, 0x1BC7C, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x1BC80, 0x1BC88, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x1BC90, 0x1BC99, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x1BC9C, 0x1BC9F, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x1BCA0, 0x1BCA3, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x1CC00, 0x1CCF9, FONT_MANAGER_UNICODE_VERSION_16_0 },
  { 0x1CD00, 0x1CEB3, FONT_MANAGER_UNICODE_VERSION_16_0 },
  { 0x1CF00, 0x1CF2D, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x1CF30, 0x1CF46, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x1CF50, 0x1CFC3, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x1D000, 0x1D0F5, FONT_MANAGER_UNICODE_VERSION_3_1 },
  { 0x1D100, 0x1D126, FONT_MANAGER_UNICODE_VERSION_3_1 },
  { 0x1D129, 0x1D129, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x1D12A, 0x1D172, FONT_MANAGER_UNICODE_VERSION_3_1 },
  { 0x1D173, 0x1D17A, FONT_MANAGER_UNICODE_VERSION_3_1 },
  { 0x1D17B, 0x1D1DD, FONT_MANAGER_UNICODE_VERSION_3_1 },
  { 0x1D1DE, 0x1D1E8, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0x1D1E9, 0x1D1EA, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x1D200, 0x1D245, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x1D2C0, 0x1D2D3, FONT_MANAGER_UNICODE_VERSION_15_0 },
  { 0x1D2E0, 0x1D2F3, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0x1D300, 0x1D356, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x1D360, 0x1D371, FONT_MANAGER_UNICODE_VERSION_5_0 },
  { 0x1D372, 0x1D378, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0x1D400, 0x1D454, FONT_MANAGER_UNICODE_VERSION_3_1 },
  { 0x1D456, 0x1D49C, FONT_MANAGER_UNICODE_VERSION_3_1 },
  { 0x1D49E, 0x1D49F, FONT_MANAGER_UNICODE_VERSION_3_1 },
  { 0x1D4A2, 0x1D4A2, FONT_MANAGER_UNICODE_VERSION_3_1 },
  { 0x1D4A5, 0x1D4A6, FONT_MANAGER_UNICODE_VERSION_3_1 },
  { 0x1D4A9, 0x1D4AC, FONT_MANAGER_UNICODE_VERSION_3_1 },
  { 0x1D4AE, 0x1D4B9, FONT_MANAGER_UNICODE_VERSION_3_1 },
  { 0x1D4BB, 0x1D4BB, FONT_MANAGER_UNICODE_VERSION_3_1 },
  { 0x1D4BD, 0x1D4C0, FONT_MANAGER_UNICODE_VERSION_3_1 },
  { 0x1D4C1, 0x1D4C1, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0x1D4C2, 0x1D4C3, FONT_MANAGER_UNICODE_VERSION_3_1 },
  { 0x1D4C5, 0x1D505, FONT_MANAGER_UNICODE_VERSION_3_1 },
  { 0x1D507, 0x1D50A, FONT_MANAGER_UNICODE_VERSION_3_1 },
  { 0x1D50D, 0x1D514, FONT_MANAGER_UNICODE_VERSION_3_1 },
  { 0x1D516, 0x1D51C, FONT_MANAGER_UNICODE_VERSION_3_1 },
  { 0x1D51E, 0x1D539, FONT_MANAGER_UNICODE_VERSION_3_1 },
  { 0x1D53B, 0x1D53E, FONT_MANAGER_UNICODE_VERSION_3_1 },
  { 0x1D540, 0x1D544, FONT_MANAGER_UNICODE_VERSION_3_1 },
  { 0x1D546, 0x1D546, FONT_MANAGER_UNICODE_VERSION_3_1 },
  { 0x1D54A, 0x1D550, FONT_MANAGER_UNICODE_VERSION_3_1 },
  { 0x1D552, 0x1D6A3, FONT_MANAGER_UNICODE_VERSION_3_1 },
  { 0x1D6A4, 0x1D6A5, FONT_MANAGER_UNICODE_VERSION_4_1 },
  { 0x1D6A8, 0x1D7C9, FONT_MANAGER_UNICODE_VERSION_3_1 },
  { 0x1D7CA, 0x1D7CB, FONT_MANAGER_UNICODE_VERSION_5_0 },
  { 0x1D7CE, 0x1D7FF, FONT_MANAGER_UNICODE_VERSION_3_1 },
  { 0x1D800, 0x1DA8B, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0x1DA9B, 0x1DA9F, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0x1DAA1, 0x1DAAF, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0x1DF00, 0x1DF1E, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x1DF25, 0x1DF2A, FONT_MANAGER_UNICODE_VERSION_15_0 },
  { 0x1E000, 0x1E006, FONT_MANAGER_UNICODE_VERSION_9_0 },
  { 0x1E008, 0x1E018, FONT_MANAGER_UNICODE_VERSION_9_0 },
  { 0x1E01B, 0x1E021, FONT_MANAGER_UNICODE_VERSION_9_0 },
  { 0x1E023, 0x1E024, FONT_MANAGER_UNICODE_VERSION_9_0 },
  { 0x1E026, 0x1E02A, FONT_MANAGER_UNICODE_VERSION_9_0 },
  { 0x1E030, 0x1E06D, FONT_MANAGER_UNICODE_VERSION_15_0 },
  { 0x1E08F, 0x1E08F, FONT_MANAGER_UNICODE_VERSION_15_0 },
  { 0x1E100, 0x1E12C, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0x1E130, 0x1E13D, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0x1E140, 0x1E149, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0x1E14E, 0x1E14F, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0x1E290, 0x1E2AE, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x1E2C0, 0x1E2F9, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0x1E2FF, 0x1E2FF, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0x1E4D0, 0x1E4F9, FONT_MANAGER_UNICODE_VERSION_15_0 },
  { 0x1E5D0, 0x1E5FA, FONT_MANAGER_UNICODE_VERSION_16_0 },
  { 0x1E5FF, 0x1E5FF, FONT_MANAGER_UNICODE_VERSION_16_0 },
  { 0x1E7E0, 0x1E7E6, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x1E7E8, 0x1E7EB, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x1E7ED, 0x1E7EE, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x1E7F0, 0x1E7FE, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x1E800, 0x1E8C4, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x1E8C7, 0x1E8D6, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x1E900, 0x1E94A, FONT_MANAGER_UNICODE_VERSION_9_0 },
  { 0x1E94B, 0x1E94B, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0x1E950, 0x1E959, FONT_MANAGER_UNICODE_VERSION_9_0 },
  { 0x1E95E, 0x1E95F, FONT_MANAGER_UNICODE_VERSION_9_0 },
  { 0x1EC71, 0x1ECB4, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0x1ED01, 0x1ED3D, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0x1EE00, 0x1EE03, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x1EE05, 0x1EE1F, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x1EE21, 0x1EE22, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x1EE24, 0x1EE24, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x1EE27, 0x1EE27, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x1EE29, 0x1EE32, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x1EE34, 0x1EE37, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x1EE39, 0x1EE39, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x1EE3B, 0x1EE3B, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x1EE42, 0x1EE42, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x1EE47, 0x1EE47, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x1EE49, 0x1EE49, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x1EE4B, 0x1EE4B, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x1EE4D, 0x1EE4F, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x1EE51, 0x1EE52, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x1EE54, 0x1EE54, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x1EE57, 0x1EE57, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x1EE59, 0x1EE59, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x1EE5B, 0x1EE5B, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x1EE5D, 0x1EE5D, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x1EE5F, 0x1EE5F, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x1EE61, 0x1EE62, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x1EE64, 0x1EE64, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x1EE67, 0x1EE6A, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x1EE6C, 0x1EE72, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x1EE74, 0x1EE77, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x1EE79, 0x1EE7C, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x1EE7E, 0x1EE7E, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x1EE80, 0x1EE89, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x1EE8B, 0x1EE9B, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x1EEA1, 0x1EEA3, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x1EEA5, 0x1EEA9, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x1EEAB, 0x1EEBB, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x1EEF0, 0x1EEF1, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x1F000, 0x1F02B, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x1F030, 0x1F093, FONT_MANAGER_UNICODE_VERSION_5_1 },
  { 0x1F0A0, 0x1F0AE, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x1F0B1, 0x1F0BE, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x1F0BF, 0x1F0BF, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x1F0C1, 0x1F0CF, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x1F0D1, 0x1F0DF, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x1F0E0, 0x1F0F5, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x1F100, 0x1F10A, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x1F10B, 0x1F10C, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x1F10D, 0x1F10F, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0x1F110, 0x1F12E, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x1F12F, 0x1F12F, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0x1F130, 0x1F130, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x1F131, 0x1F131, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x1F132, 0x1F13C, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x1F13D, 0x1F13D, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x1F13E, 0x1F13E, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x1F13F, 0x1F13F, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x1F140, 0x1F141, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x1F142, 0x1F142, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x1F143, 0x1F145, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x1F146, 0x1F146, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x1F147, 0x1F149, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x1F14A, 0x1F14E, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x1F14F, 0x1F156, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x1F157, 0x1F157, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x1F158, 0x1F15E, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x1F15F, 0x1F15F, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x1F160, 0x1F169, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x1F16A, 0x1F16B, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x1F16C, 0x1F16C, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0x1F16D, 0x1F16F, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0x1F170, 0x1F178, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x1F179, 0x1F179, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x1F17A, 0x1F17A, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x1F17B, 0x1F17C, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x1F17D, 0x1F17E, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x1F17F, 0x1F17F, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x1F180, 0x1F189, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x1F18A, 0x1F18D, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x1F18E, 0x1F18F, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x1F190, 0x1F190, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x1F191, 0x1F19A, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x1F19B, 0x1F1AC, FONT_MANAGER_UNICODE_VERSION_9_0 },
  { 0x1F1AD, 0x1F1AD, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0x1F1E6, 0x1F1FF, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x1F200, 0x1F200, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x1F201, 0x1F202, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x1F210, 0x1F231, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x1F232, 0x1F23A, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x1F23B, 0x1F23B, FONT_MANAGER_UNICODE_VERSION_9_0 },
  { 0x1F240, 0x1F248, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x1F250, 0x1F251, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x1F260, 0x1F265, FONT_MANAGER_UNICODE_VERSION_10_0 },
  { 0x1F300, 0x1F320, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x1F321, 0x1F32C, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x1F32D, 0x1F32F, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0x1F330, 0x1F335, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x1F336, 0x1F336, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x1F337, 0x1F37C, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x1F37D, 0x1F37D, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x1F37E, 0x1F37F, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0x1F380, 0x1F393, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x1F394, 0x1F39F, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x1F3A0, 0x1F3C4, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x1F3C5, 0x1F3C5, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x1F3C6, 0x1F3CA, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x1F3CB, 0x1F3CE, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x1F3CF, 0x1F3D3, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0x1F3D4, 0x1F3DF, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x1F3E0, 0x1F3F0, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x1F3F1, 0x1F3F7, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x1F3F8, 0x1F3FF, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0x1F400, 0x1F43E, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x1F43F, 0x1F43F, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x1F440, 0x1F440, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x1F441, 0x1F441, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x1F442, 0x1F4F7, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x1F4F8, 0x1F4F8, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x1F4F9, 0x1F4FC, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x1F4FD, 0x1F4FE, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x1F4FF, 0x1F4FF, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0x1F500, 0x1F53D, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x1F53E, 0x1F53F, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x1F540, 0x1F543, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x1F544, 0x1F54A, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x1F54B, 0x1F54F, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0x1F550, 0x1F567, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x1F568, 0x1F579, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x1F57A, 0x1F57A, FONT_MANAGER_UNICODE_VERSION_9_0 },
  { 0x1F57B, 0x1F5A3, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x1F5A4, 0x1F5A4, FONT_MANAGER_UNICODE_VERSION_9_0 },
  { 0x1F5A5, 0x1F5FA, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x1F5FB, 0x1F5FF, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x1F600, 0x1F600, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x1F601, 0x1F610, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x1F611, 0x1F611, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x1F612, 0x1F614, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x1F615, 0x1F615, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x1F616, 0x1F616, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x1F617, 0x1F617, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x1F618, 0x1F618, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x1F619, 0x1F619, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x1F61A, 0x1F61A, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x1F61B, 0x1F61B, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x1F61C, 0x1F61E, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x1F61F, 0x1F61F, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x1F620, 0x1F625, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x1F626, 0x1F627, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x1F628, 0x1F62B, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x1F62C, 0x1F62C, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x1F62D, 0x1F62D, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x1F62E, 0x1F62F, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x1F630, 0x1F633, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x1F634, 0x1F634, FONT_MANAGER_UNICODE_VERSION_6_1 },
  { 0x1F635, 0x1F640, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x1F641, 0x1F642, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x1F643, 0x1F644, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0x1F645, 0x1F64F, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x1F650, 0x1F67F, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x1F680, 0x1F6C5, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x1F6C6, 0x1F6CF, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x1F6D0, 0x1F6D0, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0x1F6D1, 0x1F6D2, FONT_MANAGER_UNICODE_VERSION_9_0 },
  { 0x1F6D3, 0x1F6D4, FONT_MANAGER_UNICODE_VERSION_10_0 },
  { 0x1F6D5, 0x1F6D5, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0x1F6D6, 0x1F6D7, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0x1F6DC, 0x1F6DC, FONT_MANAGER_UNICODE_VERSION_15_0 },
  { 0x1F6DD, 0x1F6DF, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x1F6E0, 0x1F6EC, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x1F6F0, 0x1F6F3, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x1F6F4, 0x1F6F6, FONT_MANAGER_UNICODE_VERSION_9_0 },
  { 0x1F6F7, 0x1F6F8, FONT_MANAGER_UNICODE_VERSION_10_0 },
  { 0x1F6F9, 0x1F6F9, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0x1F6FA, 0x1F6FA, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0x1F6FB, 0x1F6FC, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0x1F700, 0x1F773, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x1F774, 0x1F776, FONT_MANAGER_UNICODE_VERSION_15_0 },
  { 0x1F77B, 0x1F77F, FONT_MANAGER_UNICODE_VERSION_15_0 },
  { 0x1F780, 0x1F7D4, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x1F7D5, 0x1F7D8, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0x1F7D9, 0x1F7D9, FONT_MANAGER_UNICODE_VERSION_15_0 },
  { 0x1F7E0, 0x1F7EB, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0x1F7F0, 0x1F7F0, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x1F800, 0x1F80B, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x1F810, 0x1F847, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x1F850, 0x1F859, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x1F860, 0x1F887, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x1F890, 0x1F8AD, FONT_MANAGER_UNICODE_VERSION_7_0 },
  { 0x1F8B0, 0x1F8B1, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0x1F8B2, 0x1F8BB, FONT_MANAGER_UNICODE_VERSION_16_0 },
  { 0x1F8C0, 0x1F8C1, FONT_MANAGER_UNICODE_VERSION_16_0 },
  { 0x1F900, 0x1F90B, FONT_MANAGER_UNICODE_VERSION_10_0 },
  { 0x1F90C, 0x1F90C, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0x1F90D, 0x1F90F, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0x1F910, 0x1F918, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0x1F919, 0x1F91E, FONT_MANAGER_UNICODE_VERSION_9_0 },
  { 0x1F91F, 0x1F91F, FONT_MANAGER_UNICODE_VERSION_10_0 },
  { 0x1F920, 0x1F927, FONT_MANAGER_UNICODE_VERSION_9_0 },
  { 0x1F928, 0x1F92F, FONT_MANAGER_UNICODE_VERSION_10_0 },
  { 0x1F930, 0x1F930, FONT_MANAGER_UNICODE_VERSION_9_0 },
  { 0x1F931, 0x1F932, FONT_MANAGER_UNICODE_VERSION_10_0 },
  { 0x1F933, 0x1F93E, FONT_MANAGER_UNICODE_VERSION_9_0 },
  { 0x1F93F, 0x1F93F, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0x1F940, 0x1F94B, FONT_MANAGER_UNICODE_VERSION_9_0 },
  { 0x1F94C, 0x1F94C, FONT_MANAGER_UNICODE_VERSION_10_0 },
  { 0x1F94D, 0x1F94F, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0x1F950, 0x1F95E, FONT_MANAGER_UNICODE_VERSION_9_0 },
  { 0x1F95F, 0x1F96B, FONT_MANAGER_UNICODE_VERSION_10_0 },
  { 0x1F96C, 0x1F970, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0x1F971, 0x1F971, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0x1F972, 0x1F972, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0x1F973, 0x1F976, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0x1F977, 0x1F978, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0x1F979, 0x1F979, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x1F97A, 0x1F97A, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0x1F97B, 0x1F97B, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0x1F97C, 0x1F97F, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0x1F980, 0x1F984, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0x1F985, 0x1F991, FONT_MANAGER_UNICODE_VERSION_9_0 },
  { 0x1F992, 0x1F997, FONT_MANAGER_UNICODE_VERSION_10_0 },
  { 0x1F998, 0x1F9A2, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0x1F9A3, 0x1F9A4, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0x1F9A5, 0x1F9AA, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0x1F9AB, 0x1F9AD, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0x1F9AE, 0x1F9AF, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0x1F9B0, 0x1F9B9, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0x1F9BA, 0x1F9BF, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0x1F9C0, 0x1F9C0, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0x1F9C1, 0x1F9C2, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0x1F9C3, 0x1F9CA, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0x1F9CB, 0x1F9CB, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0x1F9CC, 0x1F9CC, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x1F9CD, 0x1F9CF, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0x1F9D0, 0x1F9E6, FONT_MANAGER_UNICODE_VERSION_10_0 },
  { 0x1F9E7, 0x1F9FF, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0x1FA00, 0x1FA53, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0x1FA60, 0x1FA6D, FONT_MANAGER_UNICODE_VERSION_11_0 },
  { 0x1FA70, 0x1FA73, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0x1FA74, 0x1FA74, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0x1FA75, 0x1FA77, FONT_MANAGER_UNICODE_VERSION_15_0 },
  { 0x1FA78, 0x1FA7A, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0x1FA7B, 0x1FA7C, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x1FA80, 0x1FA82, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0x1FA83, 0x1FA86, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0x1FA87, 0x1FA88, FONT_MANAGER_UNICODE_VERSION_15_0 },
  { 0x1FA89, 0x1FA89, FONT_MANAGER_UNICODE_VERSION_16_0 },
  { 0x1FA8F, 0x1FA8F, FONT_MANAGER_UNICODE_VERSION_16_0 },
  { 0x1FA90, 0x1FA95, FONT_MANAGER_UNICODE_VERSION_12_0 },
  { 0x1FA96, 0x1FAA8, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0x1FAA9, 0x1FAAC, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x1FAAD, 0x1FAAF, FONT_MANAGER_UNICODE_VERSION_15_0 },
  { 0x1FAB0, 0x1FAB6, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0x1FAB7, 0x1FABA, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x1FABB, 0x1FABD, FONT_MANAGER_UNICODE_VERSION_15_0 },
  { 0x1FABE, 0x1FABE, FONT_MANAGER_UNICODE_VERSION_16_0 },
  { 0x1FABF, 0x1FABF, FONT_MANAGER_UNICODE_VERSION_15_0 },
  { 0x1FAC0, 0x1FAC2, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0x1FAC3, 0x1FAC5, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x1FAC6, 0x1FAC6, FONT_MANAGER_UNICODE_VERSION_16_0 },
  { 0x1FACE, 0x1FACF, FONT_MANAGER_UNICODE_VERSION_15_0 },
  { 0x1FAD0, 0x1FAD6, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0x1FAD7, 0x1FAD9, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x1FADA, 0x1FADB, FONT_MANAGER_UNICODE_VERSION_15_0 },
  { 0x1FADC, 0x1FADC, FONT_MANAGER_UNICODE_VERSION_16_0 },
  { 0x1FADF, 0x1FADF, FONT_MANAGER_UNICODE_VERSION_16_0 },
  { 0x1FAE0, 0x1FAE7, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x1FAE8, 0x1FAE8, FONT_MANAGER_UNICODE_VERSION_15_0 },
  { 0x1FAE9, 0x1FAE9, FONT_MANAGER_UNICODE_VERSION_16_0 },
  { 0x1FAF0, 0x1FAF6, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x1FAF7, 0x1FAF8, FONT_MANAGER_UNICODE_VERSION_15_0 },
  { 0x1FB00, 0x1FB92, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0x1FB94, 0x1FBCA, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0x1FBCB, 0x1FBEF, FONT_MANAGER_UNICODE_VERSION_16_0 },
  { 0x1FBF0, 0x1FBF9, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0x1FFFE, 0x1FFFF, FONT_MANAGER_UNICODE_VERSION_2_0 },
  { 0x20000, 0x2A6D6, FONT_MANAGER_UNICODE_VERSION_3_1 },
  { 0x2A6D7, 0x2A6DD, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0x2A6DE, 0x2A6DF, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x2A700, 0x2B734, FONT_MANAGER_UNICODE_VERSION_5_2 },
  { 0x2B735, 0x2B738, FONT_MANAGER_UNICODE_VERSION_14_0 },
  { 0x2B739, 0x2B739, FONT_MANAGER_UNICODE_VERSION_15_0 },
  { 0x2B740, 0x2B81D, FONT_MANAGER_UNICODE_VERSION_6_0 },
  { 0x2B820, 0x2CEA1, FONT_MANAGER_UNICODE_VERSION_8_0 },
  { 0x2CEB0, 0x2EBE0, FONT_MANAGER_UNICODE_VERSION_10_0 },
  { 0x2EBF0, 0x2EE5D, FONT_MANAGER_UNICODE_VERSION_15_1 },
  { 0x2F800, 0x2FA1D, FONT_MANAGER_UNICODE_VERSION_3_1 },
  { 0x2FFFE, 0x2FFFF, FONT_MANAGER_UNICODE_VERSION_2_0 },
  { 0x30000, 0x3134A, FONT_MANAGER_UNICODE_VERSION_13_0 },
  { 0x31350, 0x323AF, FONT_MANAGER_UNICODE_VERSION_15_0 },
  { 0x3FFFE, 0x3FFFF, FONT_MANAGER_UNICODE_VERSION_2_0 },
  { 0x4FFFE, 0x4FFFF, FONT_MANAGER_UNICODE_VERSION_2_0 },
  { 0x5FFFE, 0x5FFFF, FONT_MANAGER_UNICODE_VERSION_2_0 },
  { 0x6FFFE, 0x6FFFF, FONT_MANAGER_UNICODE_VERSION_2_0 },
  { 0x7FFFE, 0x7FFFF, FONT_MANAGER_UNICODE_VERSION_2_0 },
  { 0x8FFFE, 0x8FFFF, FONT_MANAGER_UNICODE_VERSION_2_0 },
  { 0x9FFFE, 0x9FFFF, FONT_MANAGER_UNICODE_VERSION_2_0 },
  { 0xAFFFE, 0xAFFFF, FONT_MANAGER_UNICODE_VERSION_2_0 },
  { 0xBFFFE, 0xBFFFF, FONT_MANAGER_UNICODE_VERSION_2_0 },
  { 0xCFFFE, 0xCFFFF, FONT_MANAGER_UNICODE_VERSION_2_0 },
  { 0xDFFFE, 0xDFFFF, FONT_MANAGER_UNICODE_VERSION_2_0 },
  { 0xE0001, 0xE0001, FONT_MANAGER_UNICODE_VERSION_3_1 },
  { 0xE0020, 0xE007F, FONT_MANAGER_UNICODE_VERSION_3_1 },
  { 0xE0100, 0xE01EF, FONT_MANAGER_UNICODE_VERSION_4_0 },
  { 0xEFFFE, 0xEFFFF, FONT_MANAGER_UNICODE_VERSION_2_0 },
  { 0xF0000, 0xFFFFD, FONT_MANAGER_UNICODE_VERSION_2_0 },
  { 0xFFFFE, 0xFFFFF, FONT_MANAGER_UNICODE_VERSION_2_0 },
};

static const gchar unicode_version_strings[] =
  "1.1\0"
  "2.0\0"
  "2.1\0"
  "3.0\0"
  "3.1\0"
  "3.2\0"
  "4.0\0"
  "4.1\0"
  "5.0\0"
  "5.1\0"
  "5.2\0"
  "6.0\0"
  "6.1\0"
  "6.2\0"
  "6.3\0"
  "7.0\0"
  "8.0\0"
  "9.0\0"
  "10.0\0"
  "11.0\0"
  "12.0\0"
  "12.1\0"
  "13.0\0"
  "14.0\0"
  "15.0\0"
  "15.1\0"
  "16.0\0"
  ;

static const guint16 unicode_version_string_offsets[] =
{
  0,
  4,
  8,
  12,
  16,
  20,
  24,
  28,
  32,
  36,
  40,
  44,
  48,
  52,
  56,
  60,
  64,
  68,
  72,
  77,
  82,
  87,
  92,
  97,
  102,
  107,
  112,
};

#endif

